#! /bin/bash
#--------------------------------------------------------------------------------------------------#
#uninstallApp 卸载app  如果 osfusionservice进程未启动 以root身份启动进程
#编写人 lwh
#日期 2021.3.15
#功能
#参数1:app程序名
#参数2:app版本号 (暂时未使用)
#返回: 0 成功
#--------------------------------------------------------------------------------------------------#
uninstallApp() {
    local appName=$1
    local appVersion=$2
    local action=$3
    local runKbox=$(systemctl status pckbox-manager.service |grep "active (running)")
    if [ -z "$runKbox" ]; then
        echo "kbox manager 未启动"
        return 0
    fi
    local proc=$(ps aux | grep Kbox | grep osfusionservice | grep -v grep)
    if [ -z "$proc" ]; then
        echo "osfusionservice is null"
        return 0
    fi
    #检查进程是否存在 存在卸载 不存在退出
    #查询app是否存在

    case "$action" in
    remove | deconfigure)
        echo "-------------------删除----------------------"
        (timeout 60 bash /usr/bin/android-appmgr.sh uninstall $appName)
        return 0
        ;;
    esac
    echo "-------------------升级----------------------"
    (timeout 60 bash /usr/bin/android-appmgr.sh uninstall -k $appName)

    # check=$(android-appmgr.sh package-list 2>&1)
    # echo $check
    # if [ "$check" ];then
    #     if [[ "$check" == *$appName* ]];then  #存在卸载
    #         (. android-appmgr.sh  uninstall -k $appName)
    #     fi
    # fi
    return 0
}

#--------------------------------------------------------------------------------------------------#
#app preinst 统一调用脚本
#编写人 lwh
#日期 2021.1.2
#功能 app安装前脚本 检查架构及系统版本
#参数1:app程序名 (暂时未使用)
#参数2:app版本号 (暂时未使用)
#返回: 0 成功 1 架构&系统错误 2 架构错误 3 系统错误
#--------------------------------------------------------------------------------------------------#
#-------------------------------判断当前语言环境------------------------------------------------------#
getLaung() {
    zh_CN=zh_CN.UTF-8
    zh_TW=zh_TW.UTF-8
    zh_HK=zh_HK.UTF-8
    en_US=en_US.UTF-8
    curLANG=$LANG
    if [ -z $curLANG ]; then
        echo "error lang"
        local pid=$(ps aux | grep deepin-app-store | grep -v grep | grep -v daemo | awk -F ' ' '{print $2}')
        curLANG=$(cat /proc/$pid/environ | tr '\0' '\n' | grep LANG= | awk -F '=' '{print $2}')
    fi
    
    if [ -z $curLANG ]; then
        echo "error lang deepin-app-store"
        local pid=$(ps aux | grep dde-desktop | grep -v grep | awk -F ' ' '{print $2}')
        curLANG=$(cat /proc/$pid/environ | tr '\0' '\n' | grep LANG= | awk -F '=' '{print $2}')
    fi

    if [ -z $curLANG ]; then
        echo "error dde-desktop"
        return 0
    fi
    
    echo "LANG = $curLANG"
    if [ "$zh_CN" == "$curLANG" ] || [ "$zh_TW" == "$curLANG" ] || [ "$zh_HK" == "$curLANG" ]; then
        return 0
    else
        return 1
    fi
}
#---------------------------------判断cpu架构-------------------------------------------------------#
getCpu() {
    DefualtCPU="0x48" # 鲲鹏标识符
    CPU=$(cat /proc/cpuinfo | grep "CPU implementer" | uniq | awk -F ':' '{print $2}' | sed 's/ //g')
    echo "CPU = $CPU"
    if [ "$CPU" ]; then
        if [ "$CPU" == "$DefualtCPU" ]; then
            return 0
        fi
    fi

    /usr/bin/kboxcheck_hw_qs
    res=$?
    if [ "$res" -eq "0" ];then
        return 0
    fi

    return 1
}
#---------------------------------判断系统版本-------------------------------------------------------#
getOS() {
    DefualtOS=1030
    OS=$(cat /etc/os-version | grep MinorVersion | uniq | awk -F '=' '{print $2}' | sed 's/ //g')
    echo "OS = $OS"
    if [ "$OS" ]; then
        if [ "$OS" -ge "$DefualtOS" ]; then
            return 0
        fi
    fi
    return 1
}

#---------------------------------判断显卡版本-------------------------------------------------------#
getGpu() {
    test=$([ -c /dev/dri/renderD* ] && lspci |grep -wq AMD && lspci | grep -Eq '230|520|550|340|430' && echo ok)
    if [ $test = "ok" ];then
        return 0
    fi
    return 1
}
#---------------------------------root用户调用提示框需要调用该函数--------------------------------------#
notify-send() {
    local display=$DISPLAY
    local user=$(who | grep '('$display')' | awk '{print $1}')
    local uid=$(id -u $user)
    sudo -u $user DISPLAY=$display DBUS_SESSION_BUS_ADDRESS=unix:path=/run/user/$uid/bus /usr/bin/notify-send "$@"
}
#---------------------------------调用系统提示框-----------------------------------------------------#
sendMsg() {
    zhMsg=$1
    enMsg=$2
    getLaung
    CURLANG=$?
    if [ "$CURLANG" -eq 0 ]; then
        notify-send -a "about" "$zhMsg"
    else
        notify-send -a "about" "$enMsg"
    fi
}
#---------------------------------appPreinst-------------------------------------------------------#
appPreinst() {
    getOS
    OsFlag=$?
    getCpu
    CpuFlag=$?

    #getGpu
    #GpuFlag=$?

    #if [ "$GpuFlag" -eq 1 ] ; then
    #    sendMsg "目前仅支持AMD显卡，后续版本将陆续支持其他类型显卡。" "It only supports AMD graphics cards at present and will be available for other types later."
    #    return 4
    #fi

    if [ "$CpuFlag" -eq 0 ] && [ "$OsFlag" -eq 0 ]; then
        return 0
    elif [ "$CpuFlag" -eq 1 ] && [ "$OsFlag" -eq 1 ]; then
        sendMsg "暂不支持低于1030的系统版本，且非鲲鹏平台可能存在兼容性问题。" "It only supports 1030 and later system versions and may have compatibility issues on non-Kunpeng processors."
        return 1
    elif [ "$CpuFlag" -eq 1 ]; then
        sendMsg "非鲲鹏平台可能存在兼容性问题。" "It may have compatibility issues on non-Kunpeng processors."
        return 2
    else
        sendMsg "不支持低于1030的系统版本，需要升级后才能使用。" "System earlier than 1030 version is not supported, please upgrade first."
        return 3
    fi
}

#--------------------------------------------------------------------------------------------------#
#app prerm 统一调用脚本
#编写人 lwh
#日期 2021.3.9
#功能 app卸载脚本
#参数1:app程序名 卸载用
#参数2:app版本号 (暂时未使用)
#返回: 0 成功 (该函数永远返回成功)
#--------------------------------------------------------------------------------------------------#

#---------------------------------appPrerm---------------------------------------------------------#
appPrerm() {
    uninstallApp $1 $2 $3
    return 0
}

#--------------------------------------------------------------------------------------------------#
#kboxAppLauncher postinst 调用脚本
#编写人 lwh
#日期 2021.3.9
#功能 kboxAppLauncher 升级安装脚本 兼容 kboxAppLauncher1.0.2
#--------------------------------------------------------------------------------------------------#
#----------------------------------删除上一版本残留log日志--------------------------------------------#
clean_old_log() {
    rm -rf /home/*/.KboxAppLauncher
}

#-------------------------------------KboxLaunch_postinst------------------------------------------#
KboxLaunch_postinst() {
    clean_old_log
    chmod 666 /usr/share/log/log.txt
    chmod 666 /usr/share/config/android_app.json
}

#--------------------------------------------------------------------------------------------------#
#main 调用脚本
#编写人 lwh
#日期 2021.1.3
#功能 app 安装卸载  KboxAppLauncher 升级脚本调用
#参数1:操作符 确认调用函数
#参数2:app程序名 卸载用
#参数3:app版本号 (暂时未使用)
#返回: 0 成功 1 参数个数太少 2 参数个数太少或参数不正确
#--------------------------------------------------------------------------------------------------#
#-----------------------------------------main-----------------------------------------------------#



printError()
{
    echo "error : 参数个数太少或参数不正确  "
    echo "用法: KboxAndroidApp.sh appCheck appName appVersion [upgrade|remove|install]"
    echo "  或: KboxAndroidApp.sh appUninstall appName appVersion [upgrade|remove|install]"
    echo "  或: KboxAndroidApp.sh KboxLaunch_postinst"
}


main() {
    if [ $# -eq 0 ]; then
        printError
        return 1
    fi

    if [ $1 == "KboxLaunch_postinst" ]; then
        KboxLaunch_postinst
        return 0
    fi

    if [ $# -lt 3 ]; then
        printError
        return 2
    fi

    local action=upgrade
    if [ $# -eq 4 ]; then
        action=$4
    fi

    if [ $1 == "appCheck" ]; then
        appPreinst $2 $3 $action
    elif [ $1 == "appUninstall" ]; then
        echo "进入Prerm"
        appPrerm $2 $3 $action
        return 0
    else
        printError
        return 2
    fi
}
#---------------------------------------调用逻辑----------------------------------------------------#

main $@
exit $?
